pub struct SHA512Internal<PARAMS: SHA2Params> { /* private fields */ }Expand description
Internal struct for SHA512. This uses a private bound so that you cannot instantiate it directly and have to use the provided and NIST-approved parameters.
Implementations
Sourceimpl<PARAMS: SHA2Params> SHA512Internal<PARAMS>
impl<PARAMS: SHA2Params> SHA512Internal<PARAMS>